@@ -6,6 +6,9 @@ import matplotlib
 import matplotlib.pyplot as plt
 import seaborn as sns
 from scipy.stats import norm
+from sklearn.model_selection import train_test_split 
+from sklearn.linear_model import LinearRegression
+from sklearn import metrics
 
 def EOQ(demand, mean, STD, C, Ce, Cs, Ct):
   Qs=math.sqrt(2*Ct*demand/Ce)
@@ -251,4 +254,42 @@ def safetyStockwtServiceRateList(file,serviceRate,leadTimeInDays):
         reorder_point = safety_stock+avg_sales*leadTimeInDays
         result = result.append({'product_number': pnum, 'product_name': sales_prep['product_name'].iloc[0], 'safety_stock': safety_stock, 'reorder_point':reorder_point}, ignore_index=True)
     result.to_csv('ServiceRateSafetyStock.csv', index = False)
-    print("Saftey Stock with service rate method method", result, sep='\n')
\ No newline at end of file
+    print("Saftey Stock with service rate method method", result, sep='\n')
+    
+def cvPerProduct(file,product_number):
+    sales = pd.read_csv(file)
+    sales['ref'] = sales['ref'].astype('category')
+    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
+    sales['product_number'] = sales['product_number'].astype('category')
+    sales['product_name'] = sales['product_name'].astype('category')
+    sales = sales.loc[sales['product_number'] == product_number]
+    sales_qty = sales[['date','quantity']]
+    sales_qty = sales_qty.set_index(["date"])
+    sales_qty = sales_qty.resample('D').mean()
+    cv = sales_qty.quantity.std()/sales_qty.quantity.mean()
+    print('Coefficient of Variation')
+    print(cv)
+    
+def linearRegressionPerProduct(file,product_number):
+    sales = pd.read_csv(file)
+    sales['ref'] = sales['ref'].astype('category')
+    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
+    sales['product_number'] = sales['product_number'].astype('category')
+    sales['product_name'] = sales['product_name'].astype('category')
+    sales = sales.loc[sales['product_number'] == product_number]
+    X = sales['quantity'].values.reshape(-1,1)
+    y = sales['price'].values.reshape(-1,1)
+    X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2, random_state=0)
+    regressor = LinearRegression()  
+    regressor.fit(X_train, y_train)
+    #To retrieve the intercept:
+    print('Intercept:', regressor.intercept_)
+    #For retrieving the slope:
+    print('Slope:', regressor.coef_)
+    y_pred = regressor.predict(X_test)
+    print('Mean Absolute Error:', metrics.mean_absolute_error(y_test, y_pred))  
+    print('Mean Squared Error:', metrics.mean_squared_error(y_test, y_pred))  
+    print('Root Mean Squared Error:', np.sqrt(metrics.mean_squared_error(y_test, y_pred)))
+    plt.scatter(X_test, y_test,  color='gray')
+    plt.plot(X_test, y_pred, color='red', linewidth=2)
+    plt.show()
\ No newline at end of file
